@@ -16,12 +16,13 @@ char parser_error[256]="";
 textrope_t **parser_examine=0;
 
 cfg_field_t *
-cfg_field_new(textrope_t *tr_left, textrope_t *tr_right)
+cfg_field_new(textrope_t *tr_left, textrope_t *tr_right, int status)
 {
   cfg_field_t *cfnew;
   if (cfnew=(cfg_field_t *)malloc(sizeof(cfg_field_t)))
   {
     cfnew->next=0;
+    cfnew->status=status;
     cfnew->lvalue=textrope_dup(tr_left);
     cfnew->rvalue=textrope_dup(tr_right);
     if (!cfnew->lvalue || !cfnew->rvalue) cfg_field_destroy(&cfnew);
@@ -37,8 +38,16 @@ cfg_field_destroy(cfg_field_t **cf)
   {
     cfdel=*cf;
     *cf=(*cf)->next;
-    if (cfdel->lvalue) free(cfdel->lvalue);
-    if (cfdel->lvalue) free(cfdel->rvalue);
+    if (cfdel->lvalue)
+    {
+      bzero(cfdel->lvalue,strlen(cfdel->lvalue));
+      free(cfdel->lvalue);
+    }
+    if (cfdel->rvalue)
+    {
+      bzero(cfdel->rvalue,strlen(cfdel->rvalue));
+      free(cfdel->rvalue);
+    }
     free(cfdel);
   }
 }
