@@ -12,12 +12,17 @@
 
 typedef struct cfg_field {
   struct cfg_field *next;
+  int               status;
   char             *lvalue;
   char             *rvalue;
 } cfg_field_t;
 
+#define FLD_FOR_UPDATE  0x1
+#define FLD_FOR_INSERT  0x2
+#define FLD_FOR_INSUPD  (FLD_FOR_UPDATE | FLD_FOR_INSERT)
+
 cfg_field_t *
-cfg_field_new(textrope_t *tr_left, textrope_t *tr_right);
+cfg_field_new(textrope_t *tr_left, textrope_t *tr_right, int status);
 
 void
 cfg_field_destroy(cfg_field_t **cf);
