@@ -96,7 +96,7 @@ db_mysql_db_passwd(MYSQL *db, const char *user, const char *passwd,
       ret=ERR_SHORT_MEM;
   if ((ret==STATUS_CONTINUE) && !textrope_append(&cmd,0,user))
       ret=ERR_SHORT_MEM;
-  if ((ret==STATUS_CONTINUE) && !textrope_append(&cmd,0,"@localhost"))
+  if ((ret==STATUS_CONTINUE) && !textrope_append(&cmd,0,"@localhost with grant option"))
       ret=ERR_SHORT_MEM;
   if (ret==STATUS_CONTINUE) ret=mysql_query_tr(db,&cmd,0);
   textrope_purge(&cmd);
